==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/fa-IR/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => 'آدرس ایمیل خود را <strong>تایید کنید</strong>',
    '<strong>Your</strong> profile' => '<strong>نمايه</strong> شما',
    'Are you sure that you want to delete your account?' => 'آیا مطمئن هستید که می‌خواهید حساب خود را حذف کنید؟',
    'Confirm' => 'تایید',
    'Current password' => 'گذرواژ کنونی',
    'Delete account' => 'حذف حساب',
    'Do you really want to delete your logo image?' => 'آیا واقعا می‌خواهید عکس لوگوی خود را حذف کنید؟',
    'E-Mail' => 'ایمیل',
    'E-Mail change' => 'تغییر ایمیل',
    'Enter your password to continue' => 'برای ادامه گذرواژ خود را وارد کنید',
    'General' => 'کلی',
    'Hello' => 'درود',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'در اينجا اطلاعات موجود در نمايه كاربری خود را می‌توانيد تغيير دهيد',
    'Hide introduction tour panel on dashboard' => 'پنهان کردن توضيحات راهنما در داشبورد',
    'Invalid link! Please make sure that you entered the entire url.' => 'پیوند نامعتبر است! لطفا مطمئن شوید که آدرس را کامل وارد کرده‌اید.',
    'Language' => 'زبان',
    'Modules' => 'ماژول‌ها',
    'New E-Mail address' => 'آدرس ایمیل جدید',
    'New User name' => 'نام جدید کاربر',
    'Notifications' => 'آگهی‌ها',
    'Other users' => 'کاربران دیگر',
    'Password Recovery' => 'بازیابی گذرواژ',
    'Permissions' => 'مجوزها',
    'Profile' => 'پروفایل',
    'Profile visibility' => 'قابلیت نمایش پروفایل',
    'Registered users only' => 'تنها کاربران ثبت‌نام‌شده',
    'Save' => 'ذخیره',
    'Save profile' => 'ذخیره‌ی پروفایل',
    'The entered e-mail address is already in use by another user.' => 'ایمیل وارد شده توسط یک کاربر دیگر در حال استفاده‌ است.',
    'TimeZone' => 'منطقه زمانی',
    'Username has been changed' => 'نام کاربری تغییر کرده است',
    'Users' => 'کاربران',
    'Visible for all (also unregistered users)' => 'نمایان برای همه (همچنین کاربران ثبت‌نام‌نشده)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'یک ایمیل برای تایید به آدرس ایمیل جدید شما فرستاده‌ایم. <br /> لطفا دستورهای داخل آن‌ را دنبال کنید.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'شما درخواست تغییر ایمیل خود را داده‌اید.<br /> ایمیل جدید شما {newemail} است.<br /><br /> برای تایید آدرس ایمیل خود روی دکمه‌ی زیر کلیک کنید.',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'ايميل كنوني شما : <b>{email}</b>
براي تغيير آن از اينجا اقدام كنيد',
    'Your current password can be changed here.' => 'پسورد كنوني شما از اينجا قابل تغيير است',
    'Your e-mail address has been successfully changed to {email}.' => 'آدرس ایمیل شما با موفقیت به {email} تغییر یافت.',
    'Your friends' => 'دوستان شما',
    'Your password has been successfully changed!' => 'گذرواژ شما با موفقیت تغییر یافت!',
    '<strong>Account</strong> Settings' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>Your</strong> Account' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'All your personal data will be irrevocably deleted.' => '',
    'Blocked users' => '',
    'Changing the username can make some links unusable, for example old links to the profile.' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Do you really want to delete your icon image?' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Not registered users' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Profile Tags' => '',
    'Rich Text' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'You are currently the owner of following spaces:' => '',
    'You cannot use this username.' => '',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
    'You must transfer ownership or delete these spaces before you can delete your account.' => '',
    'Your account cannot be deleted!' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
    'Your username has been changed' => '',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/fa-IR/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => 'آدرس ایمیل خود را <strong>تایید کنید</strong>',
    '<strong>Your</strong> profile' => '<strong>نمايه</strong> شما',
    'Are you sure that you want to delete your account?' => 'آیا مطمئن هستید که می‌خواهید حساب خود را حذف کنید؟',
    'Confirm' => 'تایید',
    'Current password' => 'گذرواژ کنونی',
    'Delete account' => 'حذف حساب',
    'Do you really want to delete your logo image?' => 'آیا واقعا می‌خواهید عکس لوگوی خود را حذف کنید؟',
    'E-Mail' => 'ایمیل',
    'E-Mail change' => 'تغییر ایمیل',
    'Enter your password to continue' => 'برای ادامه گذرواژ خود را وارد کنید',
    'General' => 'کلی',
    'Hello' => 'درود',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'در اينجا اطلاعات موجود در نمايه كاربری خود را می‌توانيد تغيير دهيد',
    'Hide introduction tour panel on dashboard' => 'پنهان کردن توضيحات راهنما در داشبورد',
    'Invalid link! Please make sure that you entered the entire url.' => 'پیوند نامعتبر است! لطفا مطمئن شوید که آدرس را کامل وارد کرده‌اید.',
    'Language' => 'زبان',
    'Modules' => 'ماژول‌ها',
    'New E-Mail address' => 'آدرس ایمیل جدید',
    'New User name' => 'نام جدید کاربر',
    'Notifications' => 'آگهی‌ها',
    'Other users' => 'کاربران دیگر',
    'Password Recovery' => 'بازیابی گذرواژ',
    'Permissions' => 'مجوزها',
    'Profile' => 'پروفایل',
    'Profile visibility' => 'قابلیت نمایش پروفایل',
    'Registered users only' => 'تنها کاربران ثبت‌نام‌شده',
    'Save' => 'ذخیره',
    'Save profile' => 'ذخیره‌ی پروفایل',
    'The entered e-mail address is already in use by another user.' => 'ایمیل وارد شده توسط یک کاربر دیگر در حال استفاده‌ است.',
    'TimeZone' => 'منطقه زمانی',
    'Username has been changed' => 'نام کاربری تغییر کرده است',
    'Users' => 'کاربران',
    'Visible for all (also unregistered users)' => 'نمایان برای همه (همچنین کاربران ثبت‌نام‌نشده)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'یک ایمیل برای تایید به آدرس ایمیل جدید شما فرستاده‌ایم. <br /> لطفا دستورهای داخل آن‌ را دنبال کنید.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'شما درخواست تغییر ایمیل خود را داده‌اید.<br /> ایمیل جدید شما {newemail} است.<br /><br /> برای تایید آدرس ایمیل خود روی دکمه‌ی زیر کلیک کنید.',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'ايميل كنوني شما : <b>{email}</b>
براي تغيير آن از اينجا اقدام كنيد',
    'Your current password can be changed here.' => 'پسورد كنوني شما از اينجا قابل تغيير است',
    'Your e-mail address has been successfully changed to {email}.' => 'آدرس ایمیل شما با موفقیت به {email} تغییر یافت.',
    'Your friends' => 'دوستان شما',
    'Your password has been successfully changed!' => 'گذرواژ شما با موفقیت تغییر یافت!',
    '<strong>Account</strong> Settings' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>Your</strong> Account' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'All your personal data will be irrevocably deleted.' => '',
    'Blocked users' => '',
    'Changing the username can make some links unusable, for example old links to the profile.' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Do you really want to delete your icon image?' => '',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Not registered users' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Profile Tags' => '',
    'Rich Text' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'You are currently the owner of following spaces:' => '',
    'You cannot use this username.' => '',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => '',
    'You must transfer ownership or delete these spaces before you can delete your account.' => '',
    'Your account cannot be deleted!' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
    'Your username has been changed' => '',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => '',
];
